@@ -63,6 +63,7 @@ class pytwitter:
       Returns: Output from the server in the requested format (e.g. json)
       """
       # Some methods are POST only. Default to sending a GET.
+      # TODO(nsheridan): replace the hard-coded list with retrying with a POST
       use_post = False
       post_only_methods = ('statuses_update', 'statuses_delete',
           'account_end_session', 'friendships_destroy', 'friendships_create',
@@ -72,7 +73,8 @@ class pytwitter:
           'account_update_profile_background_image', 'account_update_profile',
           'notifications_follow', 'notifications_leave', 'blocks_create',
           'blocks_destroy', 'favorites_destroy', 'oauth_access_token',
-          'saved_searches_destroy', 'saved_searches_create')
+          'saved_searches_destroy', 'saved_searches_create',
+          'statuses_retweet', 'report_spam')
       if _method in post_only_methods:
         use_post = True
       # Exception case for 'direct_messages' and 'saved_searches'
@@ -86,6 +88,9 @@ class pytwitter:
         #  saved_searches.format
         #  saved_searches/method.format
         _method = re.sub(r'^(saved_searches)_(.+)$', r'\1/\2', _method)
+      elif 'report_spam' in _method:
+        # report_spam.format
+        pass
       else:
         # Everything else.
         _method = _method.replace('_', '/', 1)
